
# =====================================================================================================================
# **NOTICE**
# THIS IS A GENERATED FILE USING THE SOURCE FILE:
#  crab\utilities\java\seeq-utilities\src\main\java\com\seeq\utilities\SeeqNames.java
# =====================================================================================================================

class SeeqNames:
    class Logging:
        class RemoteAgents:
            m_d_c_filename_key = 'agentlogfilename'
        
        class Appserver:
            m_d_c_filename_key = 'logfilename'
            default_file = 'appserver'
            startup_file = 'appserver-startup'
            upgrade_file = 'appserver-upgrade'
            async_upgrade_file = 'appserver-async-upgrade'
            licensing_file = 'appserver-licensing'
            requests = 'appserver-requests'
            request_monitors = 'appserver-requestmonitors'
            units = 'appserver-units'
            users = 'appserver-users'
            class IntervalAnalysis:
                fetch_critic = 'appserver-intervalanalysis-fetchcritic'
            
        
    
    class LocalDatasources:
        class Monitors:
            datasource_class = 'Monitors'
            datasource_id = 'monitors'
            datasource_name = 'Seeq Monitors'
        
        class Authentication:
            datasource_class = 'Auth'
            datasource_id = 'Seeq'
            datasource_name = 'Seeq'
        
        class FileSignalStorage:
            datasource_class = 'Seeq - Signal Datasource'
            datasource_id = 'Signal Datasource'
            datasource_name = 'Seeq Signal Datasource'
        
        class FileSignalCache:
            datasource_class = 'Seeq - FileSignal'
            datasource_id = 'default'
            datasource_name = 'Seeq Cache'
        
        class Timescale:
            datasource_class = 'Timescale'
            datasource_id = 'default'
            datasource_name = 'Seeq Database'
        
        class Datafile:
            datasource_class = 'Imported CSV Files'
            datasource_id = 'Imported CSV Files'
            datasource_name = 'Imported CSV Files'
        
        class Cassandra:
            datasource_class = 'cassandraV2'
            datasource_id = 'default'
            datasource_name = 'Seeq Database'
        
    
    class SwaggerApiNames:
        agents = 'Agents'
        ancillaries = 'Ancillaries'
        audit = 'Audit'
        auth = 'Auth'
        assets = 'Assets'
        folders = 'Folders'
        networks = 'Networks'
        items = 'Items'
        reports = 'Reports'
        jobs = 'Jobs'
        logs = 'Logs'
        trees = 'Trees'
        sample_series = 'SampleSeries'
        signals = 'Signals'
        capsules = 'Capsules'
        conditions = 'Conditions'
        metrics = 'Metrics'
        formulas = 'Formulas'
        functions = 'Functions'
        requests = 'Requests'
        tables = 'Tables'
        workbooks = 'Workbooks'
        worksheets = 'Worksheets'
        export = 'Export'
        annotations = 'Annotations'
        datasources = 'Datasources'
        datafiles = 'Datafiles'
        users = 'Users'
        user_groups = 'UserGroups'
        access_keys = 'AccessKeys'
        data_consumption = 'DataConsumption'
        scalars = 'Scalars'
        subscriptions = 'Subscriptions'
        system = 'System'
        import_ = 'Import'
        monitors = 'Monitors'
        projects = 'Projects'
        content = 'Content'
    
    class Channels:
        agents_status = 'agents-status'
        broadcast = 'broadcast'
        live_screenshot = 'live-screenshot'
        async_response = 'async-response'
        requests_progress = 'requests-progress'
        workbook_channel = 'workbook'
        workstep_channel = 'workstep'
        report_update_channel = 'report-update'
    
    class API:
        ace = '/ace'
        agents = '/agents'
        audit = '/audit'
        auth = '/auth'
        ancillaries = '/ancillaries'
        assets = '/assets'
        folders = '/folders'
        networks = '/networks'
        items = '/items'
        reports = '/reports'
        jobs = '/jobs'
        logs = '/logs'
        batch = '/batch'
        trees = '/trees'
        asset_trees = '/trees/assets'
        sample_series = '/sample-series'
        signals = '/signals'
        samples = '/samples'
        plot_samples = '/plot-samples'
        capsules = '/capsules'
        conditions = '/conditions'
        metrics = '/metrics'
        thresholds = '/thresholds'
        formulas = '/formulas'
        docs = '/docs'
        functions = '/functions'
        scalars = '/scalars'
        properties = '/properties'
        requests = '/requests'
        tables = '/tables'
        workbooks = '/workbooks'
        worksheets = '/worksheets'
        worksteps = '/worksteps'
        export = '/export'
        annotations = '/annotations'
        datasources = '/datasources'
        datafiles = '/datafiles'
        users = '/users'
        user_groups = '/usergroups'
        access_keys = '/accesskeys'
        o_data = '/odata.svc'
        system = '/system'
        import_ = '/import'
        status = '/status'
        screenshots = '/screenshots'
        subscriptions = '/subscriptions'
        monitors = '/system/monitors'
        configuration = '/system/configuration'
        projects = '/projects'
        content = '/content'
        date_ranges = '/date-ranges'
        class ExternalToolLinkType:
            window = 'window'
            tab = 'tab'
            none = 'none'
        
        class PropertyIds:
            authentication_session_id = 'com.seeq.authenticationsessionid'
            interactive_session_id = 'com.seeq.interactivesessionid'
            csrf_token = 'com.seeq.csrftoken'
            request_information = 'com.seeq.requestinformation'
        
        class Cookies:
            auth = 'sq-auth'
            csrf = 'sq-csrf'
        
        class QueryParams:
            request_id = 'requestId'
        
        class Headers:
            async_ = 'x-sq-async'
            auth = 'x-sq-auth'
            csrf = 'x-sq-csrf'
            forwarded_for = 'x-forwarded-for'
            interactive_session_id = 'Session-Id'
            request_id = 'x-sq-request-id'
            request_origin = 'x-sq-origin'
            server = 'Server'
            server_meters = 'Server-Meters'
            server_timing = 'Server-Timing'
            expect = 'Expect'
            date_range_start = 'x-sq-daterange-start'
            date_range_end = 'x-sq-daterange-end'
        
    
    class UnitTest:
        timestamp1 = '1990-03-07T09:58:20.888888Z'
        timestamp2 = '1990-04-08T10:59:21.999999Z'
        non_existent_guid = '1CB64296-FC3E-4221-9A7F-947A0AB99807'
    
    class Edges:
        owns = 'owns'
        contains = 'contains'
        member_of = 'member of'
        interested_in = 'interested in'
        replies_to = 'replies to'
        recently_accessed = 'recently accessed'
        has_worksheet = 'has worksheet'
        has_workstep = 'has workstep'
        current_workstep = 'current workstep'
        cached_by = 'cached by'
        cache_validity = 'cache validity'
        has_parameter = 'has parameter'
        has_ancillary = 'has ancillary'
        associated_to = 'associated to'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        access_for = 'access for'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        has_ace = 'has access control entry'
        has_pinned = 'has pinned'
        measuring = 'measuring'
        has_aggregation_signal = 'has aggregation signal'
        has_aggregation_formula_function = 'has aggregation formula function'
        bounded_by = 'bounded by'
        has_threshold = 'has threshold'
        has_condition_threshold = 'has condition threshold'
        renders = 'renders'
        source_worksheet = 'source worksheet'
        source_workstep = 'source workstep'
        has_date_range = 'has date range'
        has_condition = 'has condition'
        has_content = 'has content'
    
    class Types:
        asset = 'Asset'
        access_control_entry = 'AccessControlEntry'
        stored_signal = 'StoredSignal'
        caching_signal = 'CachingSignal'
        datasource = 'Datasource'
        table_datasource = 'TableDatasource'
        datafile = 'Datafile'
        calculated_signal = 'CalculatedSignal'
        signal = 'Signal'
        tree_definition = 'TreeDefinition'
        ancillary = 'Ancillary'
        identity = 'Identity'
        user = 'User'
        user_group = 'UserGroup'
        access_key = 'AccessKey'
        system_state = 'SystemState'
        export = 'Export'
        project_link = 'ProjectLink'
        external_tool = 'ExternalTool'
        base_annotation = 'BaseAnnotation'
        annotation = 'Annotation'
        report = 'Report'
        journal = 'Journal'
        reply = 'Reply'
        condition = 'Condition'
        capsule = 'Capsule'
        stored_condition = 'StoredCondition'
        caching_condition = 'CachingCondition'
        calculated_condition = 'CalculatedCondition'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        marker_series = 'MarkerSeries'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        stored_marker_series = 'StoredMarkerSeries'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        calculated_marker_series = 'CalculatedMarkerSeries'
        calculated_scalar = 'CalculatedScalar'
        formula_function = 'FormulaFunction'
        chart = 'Chart'
        threshold_metric = 'ThresholdMetric'
        folder = 'Folder'
        project = 'Project'
        content = 'Content'
        date_range = 'DateRange'
        workbook = 'Workbook'
        worksheet = 'Worksheet'
        workstep = 'Workstep'
        item = 'Item'
        item_with_owner = 'ItemWithOwner'
        type_definition = 'TypeDefinition'
    
    class TopicDocumentAttributes:
        data_seeq_content = 'data-seeq-content'
        data_seeq_content_pending = 'data-seeq-content-pending'
    
    class ActivityProperties:
        interval = 'Interval'
        category_datasource_read = 'Datasource Read'
    
    class CapsuleProperties:
        start = 'Start'
        end = 'End'
        duration = 'Duration'
        middle = 'Middle'
        count = 'Count'
        value = 'Value'
        unit = 'Unit'
        distance = 'Distance'
        similarity = 'Similarity'
        standard_deviation = 'Standard Deviation'
        sample_period = 'Sample Period'
        reference_capsule = 'Reference Capsule'
    
    class Properties:
        guid = 'GUID'
        name = 'Name'
        id = 'ID'
        description = 'Description'
        unsearchable = 'Unsearchable'
        archived = 'Archived'
        sync_token = 'Sync Token'
        number_format = 'Number Format'
        source_number_format = 'Source Number Format'
        scoped_to = 'Scoped To'
        import_item_type = 'Import Item Type'
        filename = 'Filename'
        name_row = 'Name Row'
        name_prefix = 'Name Prefix'
        name_suffix = 'Name Suffix'
        condition_name = 'Condition Name'
        first_data_row = 'First Data Row'
        description_row = 'Description Row'
        interpolation_method_row = 'Interpolation Method Row'
        maximum_interpolation_row = 'Maximum Interpolation Row'
        value_uom_row = 'Value Unit of Measure Row'
        field_delimiter = 'Field Delimiter'
        day_first_default = 'Day First Default'
        key_column_name = 'Key Column Name'
        key_column_index = 'Key Column Index'
        end_column_name = 'End Column Name'
        end_column_index = 'End Column Index'
        key_format = 'Key Format'
        time_zone = 'Time Zone'
        value_column_names = 'Value Column Names'
        value_column_indices = 'Value Column Indices'
        append = 'Append'
        validation_mode = 'Validation Mode'
        lenient_daylight_savings = 'Lenient Daylight Savings'
        datasource_class = 'Datasource Class'
        datasource_name = 'Datasource Name'
        datasource_id = 'Datasource ID'
        data_id = 'Data ID'
        data_version_check = 'Data Version Check'
        stored_in_seeq = 'Stored In Seeq'
        supports_string_signals = 'Supports String Signals'
        connection_request_timeout = 'Connection Request Timeout'
        windows_auth_mode = 'Windows Auth Mode'
        ldap_auth_mode = 'LDAP Auth Mode'
        username_password_compatible = 'Username/Password Compatible'
        username_human_readable = 'Username Human Readable'
        expect_duplicates_during_indexing = 'Expect Duplicates During Indexing'
        referenced_datasource_id = 'Referenced Datasource ID'
        referenced_datasource_class = 'Referenced Datasource Class'
        additional_groups_to_sync = 'Additional Groups To Sync'
        asset_progress = 'Asset Progress'
        asset_count = 'Asset Count'
        signal_progress = 'Signal Progress'
        signal_count = 'Signal Count'
        condition_progress = 'Condition Progress'
        condition_count = 'Condition Count'
        scalar_progress = 'Scalar Progress'
        scalar_count = 'Scalar Count'
        relationship_progress = 'Relationship Progress'
        relationship_count = 'Relationship Count'
        user_group_progress = 'UserGroup Progress'
        user_group_count = 'UserGroups Count'
        interpolation_method = 'Interpolation Method'
        source_maximum_interpolation = 'Source Maximum Interpolation'
        override_maximum_interpolation = 'Override Maximum Interpolation'
        maximum_interpolation = 'Maximum Interpolation'
        key_uom = 'Key Unit Of Measure'
        value_uom = 'Value Unit Of Measure'
        source_value_uom = 'Source Value Unit Of Measure'
        maximum_duration = 'Maximum Duration'
        cache_enabled = 'Cache Enabled'
        uncertainty_override = 'Uncertainty Override'
        metadata_properties = 'Metadata Properties'
        last_key_written = 'Last Key Written'
        request_interval_clamp = 'Request Interval Clamp'
        uom = 'Unit Of Measure'
        formula = 'Formula'
        swap_source_id = 'Swap Source ID'
        swap_key = 'Swap Key'
        cache_value = 'CacheValue'
        formula_parameters = 'FormulaParameters'
        aggregation_function = 'AggregationFunction'
        duration = 'Duration'
        period = 'Period'
        measured_item_maximum_duration = 'MeasuredItemMaximumDuration'
        bounding_condition_maximum_duration = 'BoundingConditionMaximumDuration'
        is_generated = 'Is Generated'
        export_data = 'Export Data'
        is_capsule_view = 'Is Capsule View'
        is_export_capsule_table = 'Is Export Capsule Table'
        is_autoupdate_time_range = 'Is Autoupdate Time Range'
        grid_size = 'Grid Size'
        user_email = 'User Email'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        auth_datasource_class = 'Auth Datasource Class'
        # DEPRECATED, Deprecated. See SeeqNames.java for more info
        auth_datasource_id = 'Auth Datasource Id'
        username = 'Username'
        first_name = 'First Name'
        last_name = 'Last Name'
        password_hash = 'Password Hash'
        password_hash_method = 'Password Hash Method'
        password_set_date = 'Password Set Date'
        last_login_at = 'Last Login At'
        session_duration = 'Session Duration'
        enabled = 'Enabled'
        admin = 'Admin'
        workbench = 'Workbench'
        data = 'Data'
        created_at = 'Created At'
        updated_at = 'Updated At'
        order = 'Order'
        document = 'Document'
        plain_text_document = 'Plain Text Document'
        discoverable = 'Discoverable'
        published_at = 'Published At'
        source_security_string = 'Source Security String'
        security_string = 'Security String'
        permissions_from_datasource = 'Permissions From Datasource'
        permission_inheritance_disabled = 'Permission Inheritance Disabled'
        first_admin_created = 'First Admin Created'
        u_i_config = 'UIConfig'
        dirty_cache = 'Dirty Cache'
        height = 'Height'
        width = 'Width'
        scale = 'Scale'
        timezone = 'Timezone'
        selector = 'Selector'
        last_screenshot_duration = 'Last Screenshot Duration'
        average_screenshot_duration = 'Average Screenshot Duration'
        cron_schedule = 'Cron Schedule'
        background = 'Background'
        condition_formula_now = 'Condition Formula Now'
        icon_class = 'Icon Class'
        target_url = 'Target URL'
        link_type = 'Link Type'
        window_details = 'Window Details'
        reuse_window = 'Reuse Window'
        sort_key = 'Sort Key'
    






import os
import tempfile

from pathlib import Path

import configuration.helpers as conf
import pytest

from seeq.base.system import human_readable_byte_count
from seeq.base import system


@pytest.mark.unit
def test_human_readable_byte_count_base_ten():
    '''
    Make sure we get the same results as SystemInfoTest#testHumanReadableByteCountBaseTen
    '''
    assert human_readable_byte_count(0, False, False) == '0 B'
    assert human_readable_byte_count(10, False, False) == '10 B'
    assert human_readable_byte_count(900, False, False) == '900 B'
    assert human_readable_byte_count(999, False, False) == '999 B'

    assert human_readable_byte_count(1000, False, False) == '1.00 KB'
    assert human_readable_byte_count(2000, False, False) == '2.00 KB'
    assert human_readable_byte_count(1000 * 1000 - 10, False, False) == '999.99 KB'

    assert human_readable_byte_count(1000 * 1000, False, False) == '1.00 MB'
    assert human_readable_byte_count(50 * 1000 * 1000, False, False) == '50.00 MB'
    assert human_readable_byte_count(1000 * 1000 * 1000 - 10000, False, False) == '999.99 MB'

    assert human_readable_byte_count(1000 * 1000 * 1000, False, False) == '1.00 GB'
    assert human_readable_byte_count(50 * 1000 * 1000 * 1000, False, False) == '50.00 GB'
    assert human_readable_byte_count(1000 * 1000 * 1000 * 1000 - 10000000, False, False) == '999.99 GB'

    assert human_readable_byte_count(1000 * 1000 * 1000 * 1000, False, False) == '1.00 TB'
    assert human_readable_byte_count(50 * 1000 * 1000 * 1000 * 1000, False, False) == '50.00 TB'
    assert human_readable_byte_count(1000 * 1000 * 1000 * 1000 * 1000 - 1e10, False, False) == '999.99 TB'

    assert human_readable_byte_count(1000 * 1000 * 1000 * 1000 * 1000, False, False) == '1.00 PB'
    assert human_readable_byte_count(50 * 1000 * 1000 * 1000 * 1000 * 1000, False, False) == '50.00 PB'
    assert human_readable_byte_count(1000 * 1000 * 1000 * 1000 * 1000 * 1000 - 1e13, False, False) == '999.99 PB'

    assert human_readable_byte_count(1000 * 1000 * 1000 * 1000 * 1000 * 1000, False, False) == '1.00 EB'
    assert human_readable_byte_count(50 * 1000 * 1000 * 1000 * 1000 * 1000 * 1000, False, False) == '50.00 EB'
    assert human_readable_byte_count(1000 * 1000 * 1000 * 1000 * 1000 * 1000 * 1000 - 1e16, False, False) == '999.99 EB'


@pytest.mark.unit
def test_calculate_default_optimal_heap_sizes():
    # 64-bit, 8 cpu cores for screenshot purposes
    test_64_bit_values_8_cores = [
        # physical, appserver, cassandra, jmvLink, postgres, netLink, renderer, reverse proxy, supervisor, os
        [4000, 1200, 500, 250, 500, 250, 500, 250, 300, 250],
        [8000, 2700, 1000, 500, 1000, 500, 1000, 500, 300, 500],
        [12000, 4200, 1500, 750, 1500, 750, 1500, 750, 300, 750],
        [16000, 5700, 2000, 1000, 2000, 1000, 2000, 1000, 300, 1000],
        [32000, 11700, 4000, 2000, 4000, 2000, 4000, 2000, 300, 2000],
        [64000, 27700, 8000, 4000, 8000, 4000, 4000, 4000, 300, 4000],
        [128000, 67700, 8000, 8000, 16000, 8000, 4000, 8000, 300, 8000],
        [256000, 147700, 8000, 16000, 32000, 16000, 4000, 16000, 300, 16000]
    ]

    conf.set_option('Cpu/Count', 8, '')

    for test_set in test_64_bit_values_8_cores:
        conf.set_option('Memory/System/Total', test_set[0], '')

        assert conf.get_option('Memory/Appserver/Size') == test_set[1]
        assert conf.get_option('Memory/Cassandra/Size') == test_set[2]
        assert conf.get_option('Memory/JvmLink/Size') == test_set[3]
        assert conf.get_option('Memory/Postgres/Size') == test_set[4]
        assert conf.get_option('Memory/NetLink/Size') == test_set[5]
        assert conf.get_option('Memory/Renderer/Size') == test_set[6]
        assert conf.get_option('Memory/ReverseProxy/Size') == test_set[7]
        assert conf.get_option('Memory/Supervisor/Size') == test_set[8]
        assert conf.get_option('Memory/OperatingSystem/Size') == test_set[9]
        # Uncomment the following when needing to update the test
        # print(test_set[0], end=",")
        # print(conf.get_option('Memory/Appserver/Size'), end=",")
        # print(conf.get_option('Memory/Cassandra/Size'), end=",")
        # print(conf.get_option('Memory/JvmLink/Size'), end=",")
        # print(conf.get_option('Memory/Postgres/Size'), end=",")
        # print(conf.get_option('Memory/NetLink/Size'), end=",")
        # print(conf.get_option('Memory/Renderer/Size'), end=",")
        # print(conf.get_option('Memory/ReverseProxy/Size'), end=",")
        # print(conf.get_option('Memory/Supervisor/Size'), end=",")
        # print(conf.get_option('Memory/OperatingSystem/Size'), end=",")
        # print("")

    # 64-bit, 64 cpu cores for screenshot purposes
    test_64_bit_values_64_cores = [
        # physical, appserver, cassandra, jmvLink, postgres, netLink, renderer, reverse proxy, supervisor, os
        [4000, 1200, 500, 250, 500, 250, 500, 250, 300, 250],
        [8000, 2700, 1000, 500, 1000, 500, 1000, 500, 300, 500],
        [12000, 4200, 1500, 750, 1500, 750, 1500, 750, 300, 750],
        [16000, 5700, 2000, 1000, 2000, 1000, 2000, 1000, 300, 1000],
        [32000, 11700, 4000, 2000, 4000, 2000, 4000, 2000, 300, 2000],
        [64000, 23700, 8000, 4000, 8000, 4000, 8000, 4000, 300, 4000],
        [128000, 55700, 8000, 8000, 16000, 8000, 16000, 8000, 300, 8000],
        [256000, 119700, 8000, 16000, 32000, 16000, 32000, 16000, 300, 16000],
        [512000, 279700, 8000, 32000, 64000, 32000, 32000, 32000, 300, 32000],
    ]
    conf.set_option('Cpu/Count', 64, '')
    for test_set in test_64_bit_values_64_cores:
        conf.set_option('Memory/System/Total', test_set[0], '')

        assert conf.get_option('Memory/Appserver/Size') == test_set[1]
        assert conf.get_option('Memory/Cassandra/Size') == test_set[2]
        assert conf.get_option('Memory/JvmLink/Size') == test_set[3]
        assert conf.get_option('Memory/Postgres/Size') == test_set[4]
        assert conf.get_option('Memory/NetLink/Size') == test_set[5]
        assert conf.get_option('Memory/Renderer/Size') == test_set[6]
        assert conf.get_option('Memory/ReverseProxy/Size') == test_set[7]
        assert conf.get_option('Memory/Supervisor/Size') == test_set[8]
        assert conf.get_option('Memory/OperatingSystem/Size') == test_set[9]
        # Uncomment the following when needing to update the test
        # print(test_set[0], end=",")
        # print(conf.get_option('Memory/Appserver/Size'), end=",")
        # print(conf.get_option('Memory/Cassandra/Size'), end=",")
        # print(conf.get_option('Memory/JvmLink/Size'), end=",")
        # print(conf.get_option('Memory/Postgres/Size'), end=",")
        # print(conf.get_option('Memory/NetLink/Size'), end=",")
        # print(conf.get_option('Memory/Renderer/Size'), end=",")
        # print(conf.get_option('Memory/ReverseProxy/Size'), end=",")
        # print(conf.get_option('Memory/Supervisor/Size'), end=",")
        # print(conf.get_option('Memory/OperatingSystem/Size'), end=",")
        # print("")

    conf.unset_option('Cpu/Count')
    conf.unset_option('Memory/System/Total')
    # Uncomment the following when needing to update the test
    # assert False


@pytest.mark.unit
def test_copy_tree_exclude_folder_relative_path():
    # It was discovered in CRAB-20621 that robocopy's /XD flag to exclude directories wasn't working for relative
    # paths to subdirectories. This tests system#copy_tree to be compatible with non-Windows systems.
    # See https://superuser.com/a/690842 and follow-up comments
    with tempfile.TemporaryDirectory() as src:
        tree = TestDirectoryTree(src)
        with tempfile.TemporaryDirectory() as dest:
            system.copytree(src, dest, exclude=tree.exclude)

            all_root_contents = os.listdir(dest)
            # Destination should only have KeepParent and KeepMe.txt
            assert len(all_root_contents) == 2
            assert str(tree.keep_parent_dir_relative) in all_root_contents
            assert tree.root_keep_file_name in all_root_contents

            # Destination should have only KeepParent/KeepMe subdir
            all_subdirs = os.listdir(dest / tree.keep_parent_dir_relative)
            assert len(all_subdirs) == 1
            assert tree.keep_subdir_name in all_subdirs


class TestDirectoryTree():
    def __init__(self, root):
        self.root = root
        self.keep_parent_dir_relative = Path('KeepParent')
        self.keep_subdir_name = 'KeepMe'
        self.exclude_subdir_name = 'ExcludeMe'
        self.exclude_parent_dir_relative = Path('ExcludeParent')

        self.root_keep_file_name = 'KeepMe.txt'
        self.root_exclude_file_name = 'ExcludeMe.txt'

        self.keep_subdir_relative = self.keep_parent_dir_relative / self.keep_subdir_name
        self.exclude_subdir_relative = self.keep_parent_dir_relative / self.exclude_subdir_name

        self.exclude = [str(self.exclude_parent_dir_relative), str(self.exclude_subdir_relative),
                        self.root_exclude_file_name]

        self._create_tree()

    def _create_tree(self):
        # tmpDir
        # |
        # ---- KeepMe.txt
        # -----ExcludeMe.txt
        # ---- ExcludeParent
        # ---- KeepParent
        #          |
        #          ----- KeepMe
        #          |
        #          ----- ExcludeMe
        os.makedirs(self.root / self.keep_subdir_relative)
        os.makedirs(self.root / self.exclude_parent_dir_relative)
        os.makedirs(self.root / self.exclude_subdir_relative)

        open(Path(self.root) / self.root_keep_file_name, 'a').close()
        open(Path(self.root) / self.root_exclude_file_name, 'a').close()


# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 0.49.07
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ExportPreviewV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'autoupdate_time_range': 'bool',
        'created_at': 'str',
        'href': 'str',
        'id': 'str',
        'is_archived': 'bool',
        'is_redacted': 'bool',
        'name': 'str',
        'scoped_to': 'str',
        'type': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'autoupdate_time_range': 'autoupdateTimeRange',
        'created_at': 'createdAt',
        'href': 'href',
        'id': 'id',
        'is_archived': 'isArchived',
        'is_redacted': 'isRedacted',
        'name': 'name',
        'scoped_to': 'scopedTo',
        'type': 'type',
        'updated_at': 'updatedAt'
    }

    def __init__(self, autoupdate_time_range=False, created_at=None, href=None, id=None, is_archived=False, is_redacted=False, name=None, scoped_to=None, type=None, updated_at=None):
        """
        ExportPreviewV1 - a model defined in Swagger
        """

        self._autoupdate_time_range = None
        self._created_at = None
        self._href = None
        self._id = None
        self._is_archived = None
        self._is_redacted = None
        self._name = None
        self._scoped_to = None
        self._type = None
        self._updated_at = None

        if autoupdate_time_range is not None:
          self.autoupdate_time_range = autoupdate_time_range
        if created_at is not None:
          self.created_at = created_at
        if href is not None:
          self.href = href
        if id is not None:
          self.id = id
        if is_archived is not None:
          self.is_archived = is_archived
        if is_redacted is not None:
          self.is_redacted = is_redacted
        if name is not None:
          self.name = name
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if type is not None:
          self.type = type
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def autoupdate_time_range(self):
        """
        Gets the autoupdate_time_range of this ExportPreviewV1.
        Boolean indicating if the time range for export will be updated to 'now' when the export is started.

        :return: The autoupdate_time_range of this ExportPreviewV1.
        :rtype: bool
        """
        return self._autoupdate_time_range

    @autoupdate_time_range.setter
    def autoupdate_time_range(self, autoupdate_time_range):
        """
        Sets the autoupdate_time_range of this ExportPreviewV1.
        Boolean indicating if the time range for export will be updated to 'now' when the export is started.

        :param autoupdate_time_range: The autoupdate_time_range of this ExportPreviewV1.
        :type: bool
        """

        self._autoupdate_time_range = autoupdate_time_range

    @property
    def created_at(self):
        """
        Gets the created_at of this ExportPreviewV1.
        The ISO 8601 date of when the export was created (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :return: The created_at of this ExportPreviewV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this ExportPreviewV1.
        The ISO 8601 date of when the export was created (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :param created_at: The created_at of this ExportPreviewV1.
        :type: str
        """

        self._created_at = created_at

    @property
    def href(self):
        """
        Gets the href of this ExportPreviewV1.
        The href that can be used to interact with the item

        :return: The href of this ExportPreviewV1.
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """
        Sets the href of this ExportPreviewV1.
        The href that can be used to interact with the item

        :param href: The href of this ExportPreviewV1.
        :type: str
        """
        if href is None:
            raise ValueError("Invalid value for `href`, must not be `None`")

        self._href = href

    @property
    def id(self):
        """
        Gets the id of this ExportPreviewV1.
        The ID that can be used to interact with the item

        :return: The id of this ExportPreviewV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ExportPreviewV1.
        The ID that can be used to interact with the item

        :param id: The id of this ExportPreviewV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def is_archived(self):
        """
        Gets the is_archived of this ExportPreviewV1.
        Whether item is archived

        :return: The is_archived of this ExportPreviewV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this ExportPreviewV1.
        Whether item is archived

        :param is_archived: The is_archived of this ExportPreviewV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def is_redacted(self):
        """
        Gets the is_redacted of this ExportPreviewV1.
        Whether item is redacted

        :return: The is_redacted of this ExportPreviewV1.
        :rtype: bool
        """
        return self._is_redacted

    @is_redacted.setter
    def is_redacted(self, is_redacted):
        """
        Sets the is_redacted of this ExportPreviewV1.
        Whether item is redacted

        :param is_redacted: The is_redacted of this ExportPreviewV1.
        :type: bool
        """

        self._is_redacted = is_redacted

    @property
    def name(self):
        """
        Gets the name of this ExportPreviewV1.
        The human readable name

        :return: The name of this ExportPreviewV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ExportPreviewV1.
        The human readable name

        :param name: The name of this ExportPreviewV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this ExportPreviewV1.
        The ID of the workbook to which this item is scoped. If null, the export is globally-scoped.

        :return: The scoped_to of this ExportPreviewV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this ExportPreviewV1.
        The ID of the workbook to which this item is scoped. If null, the export is globally-scoped.

        :param scoped_to: The scoped_to of this ExportPreviewV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def type(self):
        """
        Gets the type of this ExportPreviewV1.
        The type of the item

        :return: The type of this ExportPreviewV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ExportPreviewV1.
        The type of the item

        :param type: The type of this ExportPreviewV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def updated_at(self):
        """
        Gets the updated_at of this ExportPreviewV1.
        The ISO 8601 date of when the export was updated/run (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :return: The updated_at of this ExportPreviewV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this ExportPreviewV1.
        The ISO 8601 date of when the export was updated/run (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :param updated_at: The updated_at of this ExportPreviewV1.
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ExportPreviewV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 0.49.07
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ConfigurationOptionOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'advanced': 'bool',
        'allowed_values': 'str',
        'default_dependencies': 'list[str]',
        'default_description': 'str',
        'default_value': 'object',
        'description': 'str',
        'modifiable': 'bool',
        'note': 'str',
        'path': 'str',
        'registration': 'str',
        'registration_description': 'str',
        'units': 'str',
        'value': 'object'
    }

    attribute_map = {
        'advanced': 'advanced',
        'allowed_values': 'allowedValues',
        'default_dependencies': 'defaultDependencies',
        'default_description': 'defaultDescription',
        'default_value': 'defaultValue',
        'description': 'description',
        'modifiable': 'modifiable',
        'note': 'note',
        'path': 'path',
        'registration': 'registration',
        'registration_description': 'registrationDescription',
        'units': 'units',
        'value': 'value'
    }

    def __init__(self, advanced=False, allowed_values=None, default_dependencies=None, default_description=None, default_value=None, description=None, modifiable=False, note=None, path=None, registration=None, registration_description=None, units=None, value=None):
        """
        ConfigurationOptionOutputV1 - a model defined in Swagger
        """

        self._advanced = None
        self._allowed_values = None
        self._default_dependencies = None
        self._default_description = None
        self._default_value = None
        self._description = None
        self._modifiable = None
        self._note = None
        self._path = None
        self._registration = None
        self._registration_description = None
        self._units = None
        self._value = None

        if advanced is not None:
          self.advanced = advanced
        if allowed_values is not None:
          self.allowed_values = allowed_values
        if default_dependencies is not None:
          self.default_dependencies = default_dependencies
        if default_description is not None:
          self.default_description = default_description
        if default_value is not None:
          self.default_value = default_value
        if description is not None:
          self.description = description
        if modifiable is not None:
          self.modifiable = modifiable
        if note is not None:
          self.note = note
        if path is not None:
          self.path = path
        if registration is not None:
          self.registration = registration
        if registration_description is not None:
          self.registration_description = registration_description
        if units is not None:
          self.units = units
        if value is not None:
          self.value = value

    @property
    def advanced(self):
        """
        Gets the advanced of this ConfigurationOptionOutputV1.
        True if this configuration option can have ramifications for performance and stability. Consider consulting with Seeq Support before changing.

        :return: The advanced of this ConfigurationOptionOutputV1.
        :rtype: bool
        """
        return self._advanced

    @advanced.setter
    def advanced(self, advanced):
        """
        Sets the advanced of this ConfigurationOptionOutputV1.
        True if this configuration option can have ramifications for performance and stability. Consider consulting with Seeq Support before changing.

        :param advanced: The advanced of this ConfigurationOptionOutputV1.
        :type: bool
        """
        if advanced is None:
            raise ValueError("Invalid value for `advanced`, must not be `None`")

        self._advanced = advanced

    @property
    def allowed_values(self):
        """
        Gets the allowed_values of this ConfigurationOptionOutputV1.
        If present, a plain text description of the allowed values.

        :return: The allowed_values of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._allowed_values

    @allowed_values.setter
    def allowed_values(self, allowed_values):
        """
        Sets the allowed_values of this ConfigurationOptionOutputV1.
        If present, a plain text description of the allowed values.

        :param allowed_values: The allowed_values of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._allowed_values = allowed_values

    @property
    def default_dependencies(self):
        """
        Gets the default_dependencies of this ConfigurationOptionOutputV1.
        If present, the list of paths that the default value depend on.

        :return: The default_dependencies of this ConfigurationOptionOutputV1.
        :rtype: list[str]
        """
        return self._default_dependencies

    @default_dependencies.setter
    def default_dependencies(self, default_dependencies):
        """
        Sets the default_dependencies of this ConfigurationOptionOutputV1.
        If present, the list of paths that the default value depend on.

        :param default_dependencies: The default_dependencies of this ConfigurationOptionOutputV1.
        :type: list[str]
        """

        self._default_dependencies = default_dependencies

    @property
    def default_description(self):
        """
        Gets the default_description of this ConfigurationOptionOutputV1.
        If present, any additional, plain text context for the default value.

        :return: The default_description of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._default_description

    @default_description.setter
    def default_description(self, default_description):
        """
        Sets the default_description of this ConfigurationOptionOutputV1.
        If present, any additional, plain text context for the default value.

        :param default_description: The default_description of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._default_description = default_description

    @property
    def default_value(self):
        """
        Gets the default_value of this ConfigurationOptionOutputV1.
        The value that this property would have if the option has not been explicitly set to a value.

        :return: The default_value of this ConfigurationOptionOutputV1.
        :rtype: object
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """
        Sets the default_value of this ConfigurationOptionOutputV1.
        The value that this property would have if the option has not been explicitly set to a value.

        :param default_value: The default_value of this ConfigurationOptionOutputV1.
        :type: object
        """
        if default_value is None:
            raise ValueError("Invalid value for `default_value`, must not be `None`")

        self._default_value = default_value

    @property
    def description(self):
        """
        Gets the description of this ConfigurationOptionOutputV1.
        The plain text description a configuration option's purpose and any important details.

        :return: The description of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ConfigurationOptionOutputV1.
        The plain text description a configuration option's purpose and any important details.

        :param description: The description of this ConfigurationOptionOutputV1.
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")

        self._description = description

    @property
    def modifiable(self):
        """
        Gets the modifiable of this ConfigurationOptionOutputV1.
        True if the configuration option can be set by server administrators.

        :return: The modifiable of this ConfigurationOptionOutputV1.
        :rtype: bool
        """
        return self._modifiable

    @modifiable.setter
    def modifiable(self, modifiable):
        """
        Sets the modifiable of this ConfigurationOptionOutputV1.
        True if the configuration option can be set by server administrators.

        :param modifiable: The modifiable of this ConfigurationOptionOutputV1.
        :type: bool
        """
        if modifiable is None:
            raise ValueError("Invalid value for `modifiable`, must not be `None`")

        self._modifiable = modifiable

    @property
    def note(self):
        """
        Gets the note of this ConfigurationOptionOutputV1.
        A plain text note that can be set by server administrators to provide context on any configuration changes.

        :return: The note of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """
        Sets the note of this ConfigurationOptionOutputV1.
        A plain text note that can be set by server administrators to provide context on any configuration changes.

        :param note: The note of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._note = note

    @property
    def path(self):
        """
        Gets the path of this ConfigurationOptionOutputV1.
        The unique identifier of the configuration option. Slashes in the path imply a hierarchy.

        :return: The path of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this ConfigurationOptionOutputV1.
        The unique identifier of the configuration option. Slashes in the path imply a hierarchy.

        :param path: The path of this ConfigurationOptionOutputV1.
        :type: str
        """
        if path is None:
            raise ValueError("Invalid value for `path`, must not be `None`")

        self._path = path

    @property
    def registration(self):
        """
        Gets the registration of this ConfigurationOptionOutputV1.
        If present, a plain text description of when the option will take effect when it is changed.

        :return: The registration of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._registration

    @registration.setter
    def registration(self, registration):
        """
        Sets the registration of this ConfigurationOptionOutputV1.
        If present, a plain text description of when the option will take effect when it is changed.

        :param registration: The registration of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._registration = registration

    @property
    def registration_description(self):
        """
        Gets the registration_description of this ConfigurationOptionOutputV1.
        If present, any additional, plain text context for the registration value.

        :return: The registration_description of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._registration_description

    @registration_description.setter
    def registration_description(self, registration_description):
        """
        Sets the registration_description of this ConfigurationOptionOutputV1.
        If present, any additional, plain text context for the registration value.

        :param registration_description: The registration_description of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._registration_description = registration_description

    @property
    def units(self):
        """
        Gets the units of this ConfigurationOptionOutputV1.
        If present, a freeform plain text description of the units of a value.

        :return: The units of this ConfigurationOptionOutputV1.
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """
        Sets the units of this ConfigurationOptionOutputV1.
        If present, a freeform plain text description of the units of a value.

        :param units: The units of this ConfigurationOptionOutputV1.
        :type: str
        """

        self._units = units

    @property
    def value(self):
        """
        Gets the value of this ConfigurationOptionOutputV1.
        The value of the configuration option. Values can be booleans, strings, or numbers.This value can be set changed if the option is modifiable. An absent value indicates that the option has not been configured.

        :return: The value of this ConfigurationOptionOutputV1.
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ConfigurationOptionOutputV1.
        The value of the configuration option. Values can be booleans, strings, or numbers.This value can be set changed if the option is modifiable. An absent value indicates that the option has not been configured.

        :param value: The value of this ConfigurationOptionOutputV1.
        :type: object
        """

        self._value = value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConfigurationOptionOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
